%define major		22
%define	api		2.0
%define libname         %mklibname %{name} %{api} %{major}
%define develname	%mklibname %{name} -d

%define rlmajor		18
%define rlapi		18
%define rllibname	%mklibname %{name}readline %{rlapi} %{rlmajor}

Name:		guile
Version:	2.0.13
%define subrel 1
Release:	%mkrel 1
Summary:	GNU implementation of Scheme for application extensibility
License:	LGPLv2+
Group:		Development/Other
URL:		http://www.gnu.org/software/guile/guile.html
Source0:	ftp://ftp.gnu.org/pub/gnu/guile/guile-%{version}.tar.gz
Source1:	ftp://ftp.gnu.org/pub/gnu/guile/guile-%{version}.tar.gz.sig
BuildRequires:	libgmp-devel
BuildRequires:	libltdl-devel
BuildRequires:	libncurses-devel
BuildRequires:	libreadline-devel
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(bdw-gc)
# for srfi-19.test
BuildRequires:	timezone
BuildRequires:	chrpath
BuildRequires:	texinfo
Conflicts:	guile1.8 >= 1.8.8-7

%package -n %{libname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries
Requires:	%{name}-runtime = %{version}-%{release}

%package -n %{rllibname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries

%package -n %{develname}
Summary:	Development headers and static library for libguile
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{rllibname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Conflicts:	%{_lib}guile1.8-devel >= 1.8.8-7

%package runtime
Summary:        Guile runtime library
Group:          System/Libraries
Conflicts:	%{name} < 2.0.5-2

%description
GUILE (GNU's Ubiquitous Intelligent Language for Extension) is a
library implementation of the Scheme programming language, written in
C. GUILE provides a machine-independent execution platform that can
be linked in as a library during the building of extensible programs.

Install the guile package if you'd like to add extensibility to
programs that you are developing. You'll also need to install the
guile-devel package.

%description -n %{libname}
This package contains Guile shared object libraries.

%description -n %{rllibname}
This package contains Guile shared object libraries.

%description -n %{develname}
This package contains the development headers and the static library
for libguile. C headers, aclocal macros, the `guile1.4-snarf' and
`guile-config' utilities, and static `libguile' library for Guile, the
GNU Ubiquitous Intelligent Language for Extension

%description runtime
This package contains Scheme runtime for GUILE, including ice-9
Scheme module.

%prep
%setup -q -n %{name}-%{version}


#fix encodings
for i in libguile/ChangeLog*; do
	mv $i $i.old
	iconv -f ISO8859-1 -t UTF-8 $i.old -o $i
done

%build
autoreconf -vfi
%configure2_5x \
	--disable-error-on-warning \
	--disable-rpath \
	--disable-static \
	--with-threads \
	--with-pic

%make

%install
%makeinstall_std

#remove rpath
chrpath -d %{buildroot}%{_bindir}/%{name}

#we don't want these
find %{buildroot} -name "*.la" -delete

#for ghost files
touch %{buildroot}%{_datadir}/%{name}/%{api}/slibcat
touch %{buildroot}%{_datadir}/%{name}/%{api}/slib

#slib needs this
mkdir -p %{buildroot}%{_datadir}/guile/site

# Taken from Opensuse to prevent this ugly error message 
# ldconfig: /lib64/libguile-2.0.so.22.?.?-gdb.scm is not an ELF file - it has the wrong magic bytes at the start.
mkdir -p %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}
mv %{buildroot}%{_libdir}/libguile*-gdb.scm %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}/

%post
%_install_info %{name}-tut.info
%_install_info %{name}.info
%_install_info r5rs.info
%_install_info goops.info

%preun
%_remove_install_info %{name}-tut.info
%_remove_install_info %{name}.info
%_remove_install_info r5rs.info
%_remove_install_info goops.info

%triggerin -- slib
ln -sfT ../../slib %{_datadir}/guile/%{api}/slib

rm -f %{_datadir}/guile/%{mver}/slibcat
export SCHEME_LIBRARY_PATH=%{_datadir}/slib/

# Build SLIB catalog
for pre in \
    "(use-modules (ice-9 slib))" \
    "(load \"%{_datadir}/slib/guile.init\")"
do
    %{_bindir}/guile -c "$pre
        (set! implementation-vicinity (lambda () \"%{_datadir}/guile/%{api}/\"))
        (require 'new-catalog)" &> /dev/null && break
    rm -f %{_datadir}/guile/%{api}/slibcat
done
:

%triggerun -- slib
if [ "$1" = 0 -o "$2" = 0 ]; then
    rm -f %{_datadir}/guile/%{api}/slib{,cat}
fi

%files
%doc AUTHORS ChangeLog GUILE-VERSION LICENSE README THANKS
%{_bindir}/%{name}
%{_bindir}/%{name}-tools
%{_bindir}/guild
%{_libdir}/%{name}
%exclude %{_libdir}/%{name}/%{api}
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/%{api}
%{_mandir}/man1/guile.1.*
%{_infodir}/*

%files -n %{libname}
%{_libdir}/lib%{name}-%{api}.so.%{major}*

%files -n %{rllibname}
%{_libdir}/lib%{name}readline-v-%{rlapi}.so.%{rlmajor}*

%files -n %{develname}
%doc HACKING NEWS libguile/ChangeLog*
%{_bindir}/%{name}-config
%{_bindir}/%{name}-snarf
%{_datadir}/aclocal/*
%{_includedir}/%{name}
%{_libdir}/lib%{name}-%{api}.so
%{_libdir}/lib%{name}readline-v-%{rlapi}.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_datadir}/gdb/auto-load/%{_libdir}/libguile*-gdb.scm

%files runtime
%{_libdir}/%{name}/%{api}/*
%{_datadir}/%{name}/%{api}/*
# ugly workaround to not list files twice
%exclude %{_datadir}/%{name}/%{api}/slibcat
%exclude %{_datadir}/%{name}/%{api}/slib
%ghost %{_datadir}/%{name}/%{api}/slibcat
%ghost %{_datadir}/%{name}/%{api}/slib


%changelog
* Thu Oct 27 2016 luigiwalser <luigiwalser> 2.0.13-1.1.mga5
+ Revision: 1063711
- move scm file to correct location (mga#19659)
- 2.0.13 (fixes CVE-2016-8605 and CVE-2016-8606)

* Wed Oct 15 2014 umeabot <umeabot> 2.0.9-5.mga5
+ Revision: 748926
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.9-4.mga5
+ Revision: 680044
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 luigiwalser <luigiwalser> 2.0.9-3.mga5
+ Revision: 671688
- rebuild for libunistring

* Sat Oct 19 2013 umeabot <umeabot> 2.0.9-2.mga4
+ Revision: 536214
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 fwang <fwang> 2.0.9-1.mga4
+ Revision: 483288
- new version 2.0.9

* Sat Jan 12 2013 umeabot <umeabot> 2.0.6-3.mga3
+ Revision: 352954
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 cjw <cjw> 2.0.6-2.mga3
+ Revision: 339106
- add BuildRequires: texinfo

* Mon Aug 20 2012 spuhler <spuhler> 2.0.6-1.mga3
+ Revision: 282473
- upgrade to version 2.0.6
  Removed patches for older versions

  + luigiwalser <luigiwalser>
    - rebuild for libffi

* Tue Apr 03 2012 mitya <mitya> 2.0.5-4.mga2
+ Revision: 228040
+ rebuild (emptylog)

* Tue Apr 03 2012 mitya <mitya> 2.0.5-3.mga2
+ Revision: 228037
+ rebuild (emptylog)

* Mon Apr 02 2012 mitya <mitya> 2.0.5-2.mga2
+ Revision: 227981
- Split Guile runtime off the main package to make Guile 1.8/2.0 parallel installable

* Sun Feb 05 2012 wally <wally> 2.0.5-1.mga2
+ Revision: 204830
- new version 2.0.5
- rediff P10

* Wed Dec 28 2011 wally <wally> 2.0.3-2.mga2
+ Revision: 188446
- add triggerin and triggerun scripts back

* Wed Dec 28 2011 wally <wally> 2.0.3-1.mga2
+ Revision: 188386
- new version 2.0.3
- new major and api versions
- rediff P0 and P2
- sync patches with OpenSuse
- for now conflict with older guile1.8
- clean .spec

* Sun Nov 20 2011 dmorgan <dmorgan> 1.8.8-6.mga2
+ Revision: 170152
- Remove .la files

* Thu Jul 07 2011 ahmad <ahmad> 1.8.8-5.mga2
+ Revision: 119732
- Update to 1.8.8
- We don't have sparc or ppc ports
- Drop patch4 (testsuite2), fixed upstream

* Mon Apr 18 2011 rtp <rtp> 1.8.7-5.mga1
+ Revision: 87633
- backport fix for the build of the documentation

  + dmorgan <dmorgan>
    - Remove mdv macros
    - imported package guile


* Thu Feb 18 2010 Frederic Crozat <fcrozat@mandriva.com> 1.8.7-4mdv2010.1
+ Revision: 507813
- Move slib registration to versioned directory (sync with Fedora)
- run autoreconf at setup time, not build time

* Tue Feb 09 2010 Funda Wang <fwang@mandriva.org> 1.8.7-3mdv2010.1
+ Revision: 502947
- add fedora testsuite2 patch
- rebuild for new gmp

* Sun Nov 15 2009 Funda Wang <fwang@mandriva.org> 1.8.7-2mdv2010.1
+ Revision: 466127
- fix testsuite
- new version 1.8.7

* Wed Oct 07 2009 Thierry Vignaud <tvignaud@mandriva.com> 1.8.6-4mdv2010.0
+ Revision: 455514
- move huge NEWS in devel package

* Wed Feb 25 2009 Thierry Vignaud <tvignaud@mandriva.com> 1.8.6-3mdv2009.1
+ Revision: 344659
- rebuild for new libreadline

* Tue Jan 27 2009 Funda Wang <fwang@mandriva.org> 1.8.6-2mdv2009.1
+ Revision: 334494
- rebuild for new libtool

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 1.8.6-1mdv2009.1
+ Revision: 319293
- New version 1.8.6

* Sun Dec 21 2008 Funda Wang <fwang@mandriva.org> 1.8.5-2mdv2009.1
+ Revision: 317103
- drop LDFLAGS from pkgconfig file

* Fri Sep 05 2008 Emmanuel Andry <eandry@mandriva.org> 1.8.5-1mdv2009.0
+ Revision: 281322
- fix file list
- New version
- check major
- update file list

* Mon Jun 09 2008 Pixel <pixel@mandriva.com> 1.8.3-2mdv2009.0
+ Revision: 217186
- do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Nov 28 2007 Frederic Crozat <fcrozat@mandriva.com> 1.8.3-2mdv2008.1
+ Revision: 113733
- Remove patch2 and dependency on umb-scheme (deprecated)
- add triggers for slib support (fedora)

* Wed Nov 07 2007 Adam Williamson <awilliamson@mandriva.org> 1.8.3-1mdv2008.1
+ Revision: 106629
- BUGS doesn't exist any more...
- rediff 64bit-fixes.patch and slib.patch
- drop srfi-14-test.patch and rational.patch (merged upstream)
- move docs out of lib package (per lib policy)
- new devel policy
- new license policy
- new version 1.8.3


* Mon Jan 08 2007 Götz Waschk <waschk@mandriva.org> 1.8.1-7mdv2007.0
+ Revision: 105967
- bot rebuild

  + Michael Scherer <misc@mandriva.org>
    - rebuild
    - use %%rel scheme for %%mkrel
    - use fedora patch, to fix a gnucash crash, reported by goetz
      <unnamed port>: In expression (user-vicinity):
      <unnamed port>: Unbound variable: user-vicinity
      I do not really understand why the previous patch was wrong, but i am not
      a lisp master. This one comes from fedora packages, and work well with
      gnucash.

* Sun Jan 07 2007 David Walluck <walluck@mandriva.org> 1.8.1-5mdv2007.1
+ Revision: 105149
- devel package Requires: libgmp-devel

* Sun Jan 07 2007 David Walluck <walluck@mandriva.org> 1.8.1-4mdv2007.1
+ Revision: 105126
- remove references to libqthreads
- BuildRequires: libgmp-devel
  add rational patch for lilypond
- add slib patch
- 1.8.1

  + Bruno Cornec <Bruno.Cornec@mandriva.org>
    - import guile-1.6.8-3mdv2007.0

* Wed Aug 09 2006 Gtz Waschk <waschk@mandriva.org> 1.6.8-3mdv2007.0
- add slib symlink
- bump umb-scheme dep

* Tue Aug 08 2006 Gtz Waschk <waschk@mandriva.org> 1.6.8-2mdv2007.0
- fix post installation script

* Tue Aug 08 2006 Gtz Waschk <waschk@mandriva.org> 1.6.8-1mdv2007.0
- New release 1.6.8

* Wed Mar 08 2006 Michael Scherer <misc@mandriva.org> 1.6.7-9mdk
- fix requires on x86_64 ( no quick thread )
- do use file based requires

* Wed Jan 18 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.6.7-8mdk
- fix build for x86-64 - no qthreads

* Wed Oct 12 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.6.7-7mdk
- fix file list and deps for ppc - no quickthreads

* Fri Aug 26 2005 Abel Cheung <deaddog@mandriva.org> 1.6.7-6mdk
- Move some .so symlinks to main package as they are dynamically loaded
  by *.scm files (#13837)
- Prereq -> Requires (#17444)

* Sun Aug 21 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.6.7-5mdk
- add BuildRequires: libltdl-devel

* Sat Aug 20 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.6.7-4mdk
- gcc4 fixes

* Thu Feb 03 2005 Abel Cheung <deaddog@mandrake.org> 1.6.7-3mdk
- multiarch
- Fix info-install requirement

* Fri Jan 21 2005 Gtz Waschk <waschk@linux-mandrake.com> 1.6.7-2mdk
- rebuild for new readline

* Sun Dec 26 2004 Abel Cheung <deaddog@mandrake.org> 1.6.7-1mdk
- New release
- Use tar.gz (with signature)
- Move shared files out of lib package, allowing multilib

